; MC68HC908GP20 Equates
;
; I/O Ports
PORTA   EQU    $0000      ;I/O port A
PORTB   EQU    $0001      ;I/O port B
PORTC   EQU    $0002      ;I/O port C
PORTD   EQU    $0003      ;I/O port D
;
DDRA    EQU    $0004      ;Data direction for port A
DDRB    EQU    $0005      ;Data direction for port B
DDRC    EQU    $0006      ;Data direction for port C
DDRD    EQU    $0007      ;Data direction for port D
;
PORTE   EQU    $0008      ;I/O port D
DDRE    EQU    $000C      ;Data direction for port D
;
PAPUP	EQU	$000D
PCPUP	EQU	$000E
PDPUP	EQU	$000F
* Port B and Port E do not have pullup registers
*--------------------------------------------------------------------------
; SPI
SPCR	EQU	$0010
SPE	EQU	1

SPSCR	EQU	$0011
SPDR	EQU	$0012
*--------------------------------------------------------------------------
; SCI
SCC1	EQU	$0013	; SCI Control Register 1 
ENSCI   EQU	$6	; Enable SCI
;
SCC2	EQU	$0014	; SCI Control Register 2 
RE	EQU	$2	; Receive Enable
TE	EQU	$3	; Transmit Enable
;
SCC3	EQU	$0015	; SCI Control Register 3 
;
SCS1	EQU	$0016	; SCI Status Register 1
TC      EQU	$6	; Transmission complete
SCRF	EQU	$5	; SCI Receiver Full Bit
;
SCS2	EQU	$0017	; SCI Status Register 2
;
SCDR	EQU	$0018	; SCI Data Register
;
SCBR	EQU	$0019	; SCI Baud Rate Register
*--------------------------------------------------------------------------
; Configuration Registers
CONFIG2	EQU	$001E
CONFIG1	EQU	$001F
*--------------------------------------------------------------------------
; Timer Registers
T1SC	EQU	$0020	; Timer 1 Status and Control Register
TOF	EQU	7	;   Timer Overflow Flag (R)
TOIE	EQU     6	;   Timer Overflow Interrput Enable (RW) 
TSTOP	EQU	5	;   Timer Stop (RW)
TRST	EQU	4	;   Timer Reset (W)


T1CNTH	EQU	$0021	; Timer 1 Counter Register High
T1CNTL	EQU	$0022	; Timer 1 Counter Register Low

T1MODH	EQU	$0023	; Timer 1 Modulo Register High
T1MODL	EQU	$0024	; Timer 1 Modulo Register Low

T1SC0	EQU	$0025	; Timer 1 Channel 0 Status and Control Register
T1CH0H	EQU	$0026	; Timer 1 Channel 0 Register High
T1CH0L	EQU	$0027	; Timer 1 Channel 0 Register Low

T1SC1	EQU	$0028	; Timer 1 Channel 1 Status and Control Register
T1CH1H	EQU	$0029	; Timer 1 Channel 1 Register High
T1CH1L	EQU	$002A	; Timer 1 Channel 1 Register Low
;---------
T2SC	EQU	$002B	; Timer 2 Status and Control Register

T2CNTH	EQU	$002C	; Timer 2 Counter Register High
T2CNTL	EQU	$002D	; Timer 2 Counter Register Low

T2MODH	EQU	$002E	; Timer 2 Modulo Register High
T2MODL	EQU	$002F	; Timer 2 Modulo Register Low

T2SC0	EQU	$0030	; Timer 2 Channel 0 Status and Control Register
T2CH0H	EQU	$0031	; Timer 2 Channel 0 Register High
T2CH0L	EQU	$0032	; Timer 2 Channel 0 Register Low

T2SC1	EQU	$0033	; Timer 2 Channel 1 Status and Control Register
T2CH1H	EQU	$0034	; Timer 2 Channel 1 Register High
T2CH1L	EQU	$0035	; Timer 2 Channel 1 Register Low
*--------------------------------------------------------------------------
* PLL Registers
PCTL	EQU	$0036		  ; PLL Control -> P,E
PLLON	EQU	$5
BCS	EQU	$4
;
PBWC	EQU	$0037		  ; PLL Bandwidth Control (Auto)
PMSH    EQU	$0038  		  ; PLL Multiplier Select High byte
PMSL    EQU	$0039		  ; PLL Multiplier Select Low byte
PMRS	EQU	$003A		  ; PLL VCO Range Select ->L
PMDS	EQU	$003B		  ; PLL Reference Divider Select  ->R
*--------------------------------------------------------------------------
* System Registers 
SBSR		equ	$FE00	; 
SRSR		equ	$FE01	; 
SUBAR		equ	$FE02	; 
SBFCR		equ	$FE03	; 
INT1		equ	$FE04	; 
INT2		equ	$FE05	; 
INT3		equ	$FE06	; 
FLTCR		equ	$FE07	; 
FLCR		equ	$FE08	; 
BRKH		equ	$FE09	; 
BRKL		equ	$FE0A	; 
BRKSCR		equ	$FE0B	; 
LVISR		equ	$FE0C	; 
;
FLBPR		equ	$FF7F	; 
*--------------------------------------------------------------------------
VECTORS		equ     $FFDC   ; Start of Reset/Interrupt vectors

RAMstart        equ     $0040   ; Start of on chip RAM ($40 - $23F) 512 bytes 

ROMstart        equ     $B000   ; Start of program in User Flash 
*				  $B000 - $FDFF (19,968 bytes)
*============================================================================
